import os
from aqt import mw
from aqt.qt import *

from .kindle_window import KindleWindow
from . import config


addon_path = os.path.dirname(__file__)


def get_open_db_path():
    db_path = config.get('last_db_path')
    
    if db_path and os.path.isfile(db_path):
        return db_path
    
    kindle_path = QFileDialog.getExistingDirectory(mw, 'Select Kindle Folder', os.path.expanduser('~'))
    if not kindle_path:
        return None
        
    db_path = os.path.join(kindle_path, 'system', 'vocabulary', 'vocab.db')
    if not os.path.isfile(db_path):
        QMessageBox.information(mw, 'Migaku Kindle', 'No vocabulary data was found on the selected device.')
        return None

    config.set('last_db_path', db_path, do_write=True)
    return db_path


def open_dialog():
    if KindleWindow.current_instance:
        KindleWindow.current_instance.activateWindow()
        KindleWindow.current_instance.raise_()
        return

    db_path = get_open_db_path()
    if db_path is None:
        return
    dlg = KindleWindow(mw, db_path)
    dlg.show()


def setup_menu():
    add_menu = False
    if not hasattr(mw, 'MigakuMainMenu'):
        mw.MigakuMainMenu = QMenu('Migaku', mw)
        add_menu = True
    if not hasattr(mw, 'MigakuMenuSettings'):
        mw.MigakuMenuSettings = []
    if not hasattr(mw, 'MigakuMenuActions'):
        mw.MigakuMenuActions = []

    dialog_action = QAction('Kindle', mw)
    dialog_action.triggered.connect(open_dialog)
    mw.MigakuMenuActions.append(dialog_action)

    mw.MigakuMainMenu.clear()
    for act in mw.MigakuMenuSettings:
        mw.MigakuMainMenu.addAction(act)
    mw.MigakuMainMenu.addSeparator()
    for act in mw.MigakuMenuActions:
        mw.MigakuMainMenu.addAction(act)

    if add_menu:
        mw.form.menubar.insertMenu(mw.form.menuHelp.menuAction(), mw.MigakuMainMenu)


setup_menu()
