from aqt.qt import *
import anki.hooks
import aqt

from . import config

addon_path = os.path.dirname(__file__)


class NoteDialog(QDialog):

    def __init__(self, parent=None):
        super(NoteDialog, self).__init__(parent)
        
        self.setWindowTitle('Select Note')
        self.setWindowIcon(QIcon(os.path.join(addon_path, 'migaku.png')))

        self.lyt = QGridLayout(self)

        row = 0

        self.lyt.addWidget(QLabel('Note'), row, 0)
        self.model_chooser_area = QWidget()
        self.model_chooser = aqt.modelchooser.ModelChooser(aqt.mw, self.model_chooser_area, label=False)
        self.lyt.addWidget(self.model_chooser_area, row, 1)

        row += 1
        self.lyt.addWidget(QLabel('Sentence'), row, 0)
        self.sentece_cb = QComboBox()
        self.lyt.addWidget(self.sentece_cb, row, 1)

        row += 1
        self.lyt.addWidget(QLabel('Word'), row, 0)
        self.word_cb = QComboBox()
        self.lyt.addWidget(self.word_cb, row, 1)

        row += 1
        self.lyt.addWidget(QLabel('Book'), row, 0)
        self.book_cb = QComboBox()
        self.lyt.addWidget(self.book_cb, row, 1)

        anki.hooks.addHook('currentModelChanged', self.on_model_change)

        self.has_dicts = hasattr(aqt.mw, 'miDictDB')

        if self.has_dicts:
            row += 1
            self.lyt.addWidget(QLabel('Dict Output'), row, 0)
            self.dict_out_cb = QComboBox()
            self.lyt.addWidget(self.dict_out_cb, row, 1)

            dict_names = ['None']
            for d in aqt.mw.miDictDB.getAllDicts():
                dict_name = aqt.mw.miDictDB.cleanDictName(d)
                dict_names.append(dict_name)
            dict_names.append('Google Images')
            dict_names.append('Forvo')

            self.dict_cbs = []
            for i in range(3):
                row += 1
                self.lyt.addWidget(QLabel('Dict %d' % (i+1)), row, 0)
                dict_cb = QComboBox()
                self.dict_cbs.append(dict_cb)
                dict_cb.addItems(dict_names)
                self.lyt.addWidget(dict_cb, row, 1)

            row += 1
            self.lyt.addWidget(QLabel('Max Per Dict'), row, 0)
            self.max_per_dict = QSpinBox()
            self.max_per_dict.setValue(1)
            self.max_per_dict.setMinimum(1)
            self.max_per_dict.setMaximum(20)
            self.lyt.addWidget(self.max_per_dict, row, 1)

        self.update_cbs()
        self.update_dicts()

        row += 1
        self.button_box = QDialogButtonBox()
        self.button_box.addButton('OK', QDialogButtonBox.AcceptRole)
        self.lyt.addWidget(self.button_box, row, 0, 1, 2)
        self.button_box.accepted.connect(self.accept)
    

    def accept(self):
        model = aqt.mw.col.models.current()
        model_id = str(model['id'])

        sel = []
        sel.append(None if self.sentece_cb.currentIndex() < 1 else self.sentece_cb.currentText())
        sel.append(None if self.word_cb.currentIndex() < 1 else self.word_cb.currentText())
        sel.append(None if self.book_cb.currentIndex() < 1 else self.book_cb.currentText())
        config.get('notes')[model_id] = sel

        if self.has_dicts:
            dicts = []
            for dict_cb in self.dict_cbs:
                txt = dict_cb.currentText()
                if dict_cb.currentIndex() > 0:
                    dicts.append(txt)
            dict_out_fld = None
            if self.dict_out_cb.currentIndex() > 0:
                dict_out_fld = self.dict_out_cb.currentText()
            dict_data = [dicts, self.max_per_dict.value(), dict_out_fld]
            config.get('notes_dict')[model_id] = dict_data

        config.write()

        self.model_chooser.cleanup()
        QDialog.accept(self)

    def reject(self):
        self.accept()


    def update_cbs(self):
        model = aqt.mw.col.models.current()
        model_id = str(model['id'])

        self.sentece_cb.clear()
        self.word_cb.clear()
        self.book_cb.clear()

        fld_names = ['Discard']
        for fld in model['flds']:
            fld_names.append(fld['name'])
        self.sentece_cb.addItems(fld_names)
        self.word_cb.addItems(fld_names)
        self.book_cb.addItems(fld_names)

        sel = config.get('notes').get(model_id, [None,None,None])
        if sel[0]:
            self.sentece_cb.setCurrentText(sel[0])
        if sel[1]:
            self.word_cb.setCurrentText(sel[1])
        if sel[2]:
            self.book_cb.setCurrentText(sel[2])


    def update_dicts(self):
        if self.has_dicts:
            model = aqt.mw.col.models.current()
            model_id = str(model['id'])

            fld_names = ['Discard']
            for fld in model['flds']:
                fld_names.append(fld['name'])
            self.dict_out_cb.clear()
            self.dict_out_cb.addItems(fld_names)

            data = config.get('notes_dict').get(model_id, [[], 1, None])
            dicts = data[0]

            for i, dict_cb in enumerate(self.dict_cbs):
                dict_cb.setCurrentText('None')
                if len(dicts) > i:
                    dict_cb.setCurrentText(dicts[i])

            self.max_per_dict.setValue(data[1])
            if data[2]:
                self.dict_out_cb.setCurrentText(data[2])

    
    def on_model_change(self):
        self.update_cbs()
        self.update_dicts()
